@@ -302,18 +302,27 @@ def test_scipy_comp():
 
 def test1d_mask():
     data_pts = np.arange(1000)
+    # put the input locations in random order
+    np.random.shuffle(data_pts)
+    bad_idx = np.nonzero(data_pts == 400)
+    nearest_idx_1 = np.nonzero(data_pts == 399)
+    nearest_idx_2 = np.nonzero(data_pts == 390)
     kdtree = KDTree(data_pts, leafsize=15)
-    query_pts = np.arange(400, 300, -10)
+    # shift the query points just a little bit for known neighbors
+    # we want 399 as a result, not 401, when we query for ~400
+    query_pts = np.arange(399.9, 299.9, -10)
     query_mask = np.zeros(data_pts.shape[0]).astype(bool)
-    query_mask[400] = True
+    query_mask[bad_idx] = True
     dist, idx = kdtree.query(query_pts, mask=query_mask)
-    assert idx[0] == 399  # would be 400 if no mask
-    assert dist[0] == 1.
-    assert idx[1] == 390
+    assert idx[0] == nearest_idx_1  # 399, would be 400 if no mask
+    assert np.isclose(dist[0], 0.9)
+    assert idx[1] == nearest_idx_2  # 390
+    assert np.isclose(dist[1], 0.1)
 
 
 def test1d_all_masked():
     data_pts = np.arange(1000)
+    np.random.shuffle(data_pts)
     kdtree = KDTree(data_pts, leafsize=15)
     query_pts = np.arange(400, 300, -10)
     query_mask = np.ones(data_pts.shape[0]).astype(bool)
